@@ -1,16 +1,19 @@
+"""Meta-analysis functions for MOABB."""
+
 import itertools
 import logging
 
 import numpy as np
 import pandas as pd
 import scipy.stats as stats
+from sklearn.utils import check_random_state
 
 
 log = logging.getLogger(__name__)
 
 
 def collapse_session_scores(df):
-    """Prepare results dataframe for computing statistics
+    """Prepare results dataframe for computing statistics.
 
     Parameters
     ----------
@@ -23,11 +26,15 @@ def collapse_session_scores(df):
         Aggregated results, samples are index, columns are pipelines,
         and values are scores
     """
-    return df.groupby(["pipeline", "dataset", "subject"]).mean().reset_index()
+    return (
+        df.groupby(["pipeline", "dataset", "subject"])
+        .mean(numeric_only=True)
+        .reset_index()
+    )
 
 
 def compute_pvals_wilcoxon(df, order=None):
-    """Compute Wilcoxon rank-sum test on agregated results
+    """Compute Wilcoxon rank-sum test on aggregated results.
 
     Returns kxk matrix of p-values computed via the Wilcoxon rank-sum test,
     order defines the order of rows and columns
@@ -68,7 +75,7 @@ def compute_pvals_wilcoxon(df, order=None):
 
 
 def _pairedttest_exhaustive(data):
-    """Exhaustive paired t-test for permutation tests
+    """Exhaustive paired t-test for permutation tests.
 
     Returns p-values for exhaustive ttest that runs through all possible
     permutations of the first dimension. Very bad idea for size greater than 12
@@ -83,7 +90,7 @@ def _pairedttest_exhaustive(data):
     pvals: ndarray of shape (n_pipelines, n_pipelines)
         array of pvalues
     """
-    out = np.ones((data.shape[1], data.shape[1]))
+    out = np.zeros(data.shape[1:], dtype=np.int32)
     true = data.sum(axis=0)
     nperms = 2 ** data.shape[0]
     for perm in itertools.product([-1, 1], repeat=data.shape[0]):
@@ -92,15 +99,21 @@ def _pairedttest_exhaustive(data):
         # multiply permutation by subject dimension and sum over subjects
         randperm = (data * perm[:, None, None]).sum(axis=0)
         # compare to true difference (numpy autocasts bool to 0/1)
-        out += randperm > true
-    out = out / nperms
-    # control for cases where pval is 1
-    out[out == 1] = 1 - (1 / nperms)
-    return out
+        out += randperm >= true
+
+    # Correct for p-values equal to 1
+    # as they are invalid p-values for Stouffer's method.
+    # Note: as this is an exhaustive permutation test,
+    # one of the t-test is computed with the original statistic
+    # So in practice out cannot contain zeros.
+
+    out[out >= nperms] = nperms - 1
+
+    return out / nperms
 
 
-def _pairedttest_random(data, nperms):
-    """Returns p-values based on nperms permutations of a paired ttest
+def _pairedttest_random(data, nperms, seed=None):
+    """Return p-values based on nperms permutations of a paired ttest.
 
     data is a (subj, alg, alg) matrix of differences between scores for each
     pair of algorithms per subject
@@ -115,21 +128,28 @@ def _pairedttest_random(data, nperms):
     pvals: ndarray of shape (n_pipelines, n_pipelines)
         array of pvalues
     """
-    out = np.ones((data.shape[1], data.shape[1]))
+    rng = check_random_state(seed)
+    out = np.ones(data.shape[1:], dtype=np.int32)
     true = data.sum(axis=0)
     for _ in range(nperms):
-        perm = np.random.randint(2, size=(data.shape[0],))
+        perm = rng.randint(2, size=(data.shape[0],))
         perm[perm == 0] = -1
         # multiply permutation by subject dimension and sum over subjects
         randperm = (data * perm[:, None, None]).sum(axis=0)
         # compare to true difference (numpy autocasts bool to 0/1)
-        out += randperm > true
-    out[out == nperms] = nperms - 1
+        out += randperm >= true
+
+    # Correct p-values >= 1
+    # as they are invalid p-values for Stouffer's method.
+    # Note: as out is initialized with ones,
+    # it cannot contain zeros.
+
+    out[out >= nperms] = nperms - 1
     return out / nperms
 
 
-def compute_pvals_perm(df, order=None):
-    """Compute permutation test on agregated results
+def compute_pvals_perm(df, order=None, seed=None):
+    """Compute permutation test on aggregated results.
 
     Returns kxk matrix of p-values computed via permutation test,
     order defines the order of rows and columns
@@ -141,6 +161,8 @@ def compute_pvals_perm(df, order=None):
         and values are scores
     order: list
         list of length (num algorithms) with names corresponding to df columns
+    seed: int | None
+        random seed for reproducibility
 
     Returns
     -------
@@ -161,14 +183,14 @@ def compute_pvals_perm(df, order=None):
             data[:, i, j] = df.loc[:, pipe1] - df.loc[:, pipe2]
             data[:, j, i] = df.loc[:, pipe2] - df.loc[:, pipe1]
     if data.shape[0] > 13:
-        p = _pairedttest_random(data, 10000)
+        p = _pairedttest_random(data, 10000, seed=seed)
     else:
         p = _pairedttest_exhaustive(data)
     return p
 
 
 def compute_effect(df, order=None):
-    """Compute effect size across datasets
+    """Compute effect size across datasets.
 
     Returns kxk matrix of effect sizes, order defines the order of rows/columns
 
@@ -203,7 +225,7 @@ def compute_effect(df, order=None):
 
 
 def compute_dataset_statistics(df, perm_cutoff=20):
-    """Compute meta-analysis statistics from results dataframe
+    """Compute meta-analysis statistics from results dataframe.
 
     Parameters
     ----------
@@ -241,14 +263,14 @@ def compute_dataset_statistics(df, perm_cutoff=20):
 
 
 def combine_effects(effects, nsubs):
-    """Combining effects for meta-analysis statistics
+    """Combine effects for meta-analysis statistics.
 
     Function that takes effects from each experiments and number of subjects to
     return meta-analysis effect
 
     Parameters
     ----------
-    p: DataFrame
+    effects: DataFrame
         effects for 2 pipelines computed on different datasets
     nsubs: float
         average number of subject per datasets
@@ -256,7 +278,7 @@ def combine_effects(effects, nsubs):
     Returns
     -------
     effect: float
-        Estimatation of the combined p-value
+        Estimatation of the combined effects
     """
     W = np.sqrt(nsubs)
     W = W / W.sum()
@@ -264,7 +286,7 @@ def combine_effects(effects, nsubs):
 
 
 def combine_pvalues(p, nsubs):
-    """Combining p-values for meta-analysis statistics
+    """Combine p-values for meta-analysis statistics.
 
     Function that takes pvals from each experiments and number of subjects to
     return meta-analysis significance using Stouffer's method
@@ -290,10 +312,10 @@ def combine_pvalues(p, nsubs):
 
 
 def find_significant_differences(df, perm_cutoff=20):
-    """Compute differences between pipelines across datasets
+    """Compute differences between pipelines across datasets.
 
-    Compute matrix of p-values for all algorithms over all datasets via
-    combined p-values method
+    Compute matrices of p-values and effects for all algorithms over all datasets via
+    combined p-values and combined effects methods
 
     Parameters
     ----------
@@ -316,8 +338,8 @@ def find_significant_differences(df, perm_cutoff=20):
     nsubs = np.array([df.loc[df.dataset == d, "nsub"].mean() for d in dsets])
     P_full = df.pivot_table(values="p", index=["dataset", "pipe1"], columns="pipe2")
     T_full = df.pivot_table(values="smd", index=["dataset", "pipe1"], columns="pipe2")
-    P = np.full((len(algs), len(algs)), np.NaN)
-    T = np.full((len(algs), len(algs)), np.NaN)
+    P = np.full((len(algs), len(algs)), np.nan)
+    T = np.full((len(algs), len(algs)), np.nan)
     for i in range(len(algs)):
         for j in range(len(algs)):
             if i != j:
