@@ -2,6 +2,7 @@ import hashlib
 import os
 import os.path as osp
 import re
+import warnings
 from datetime import datetime
 
 import h5py
@@ -10,6 +11,17 @@ import pandas as pd
 from mne import get_config, set_config
 from mne.datasets.utils import _get_path
 from sklearn.base import BaseEstimator
+from sklearn.pipeline import Pipeline
+
+from moabb.utils import _open_lock_hdf5
+
+
+try:
+    from codecarbon import EmissionsTracker  # noqa
+
+    _carbonfootprint = True
+except ImportError:
+    _carbonfootprint = False
 
 
 def get_string_rep(obj):
@@ -17,7 +29,19 @@ def get_string_rep(obj):
         str_repr = repr(obj.get_params())
     else:
         str_repr = repr(obj)
-    str_no_addresses = re.sub("0x[a-z0-9]*", "0x__", str_repr)
+    if "<lambda> at " in str_repr:
+        warnings.warn(
+            "You are probably using a classifier with a lambda function"
+            " as an attribute. Lambda functions can only be identified"
+            " by memory address which MOABB does not consider. To avoid"
+            " issues you can use named functions defined using the def"
+            " keyword instead.",
+            RuntimeWarning,
+            stacklevel=2,
+        )
+    str_no_addresses = re.sub(
+        "0x[\w]+>", "0x__", str_repr
+    )  # \w also includes _ for address such as 0x__
     return str_no_addresses.replace("\n", "").encode("utf8")
 
 
@@ -29,6 +53,11 @@ def get_digest(obj):
     return hashlib.md5(get_string_rep(obj)).hexdigest()
 
 
+def get_pipeline_digest(process_pipeline, clf_pipeline):
+    full_pipeline = Pipeline(steps=[("process", process_pipeline), ("clf", clf_pipeline)])
+    return get_digest(full_pipeline)
+
+
 class Results:
     """Class to hold results from the evaluation.evaluate method.
 
@@ -37,7 +66,6 @@ class Results:
 
     Saves dataframe per pipeline and can query to see if particular
     subject has already been run
-
     """
 
     def __init__(
@@ -49,9 +77,7 @@ class Results:
         hdf5_path=None,
         additional_columns=None,
     ):
-        """
-        class that will abstract result storage
-        """
+        """Class that will abstract result storage."""
         from moabb.evaluations.base import BaseEvaluation
         from moabb.paradigms.base import BaseParadigm
 
@@ -87,18 +113,18 @@ class Results:
             os.remove(self.filepath)
 
         if not osp.isfile(self.filepath):
-            with h5py.File(self.filepath, "w") as f:
-                f.attrs["create_time"] = np.string_(
+            with _open_lock_hdf5(self.filepath, "w") as f:
+                f.attrs["create_time"] = np.bytes_(
                     "{:%Y-%m-%d, %H:%M}".format(datetime.now())
                 )
 
-    def add(self, results, pipelines):
-        """add results"""
+    def add(self, results, pipelines, process_pipeline):  # noqa: C901
+        """Add results."""
 
         def to_list(res):
-            if type(res) is dict:
+            if isinstance(res, dict):
                 return [res]
-            elif type(res) is not list:
+            elif not isinstance(res, list):
                 raise ValueError(
                     "Results are given as neither dict nor"
                     "list but {}".format(type(res).__name__)
@@ -106,11 +132,18 @@ class Results:
             else:
                 return res
 
-        with h5py.File(self.filepath, "r+") as f:
+        col_names = ["score", "time", "samples"]
+        if _carbonfootprint:
+            n_cols = 4
+            col_names.append("carbon_emission")
+        else:
+            n_cols = 3
+
+        with _open_lock_hdf5(self.filepath, "r+") as f:
             for name, data_dict in results.items():
-                digest = get_digest(pipelines[name])
+                digest = get_pipeline_digest(process_pipeline, pipelines[name])
                 if digest not in f.keys():
-                    # create pipeline main group if nonexistant
+                    # create pipeline main group if nonexistent
                     f.create_group(digest)
 
                 ppline_grp = f[digest]
@@ -122,19 +155,21 @@ class Results:
                 dname = d1["dataset"].code
                 n_add_cols = len(self.additional_columns)
                 if dname not in ppline_grp.keys():
-                    # create dataset subgroup if nonexistant
+                    # create dataset subgroup if nonexistent
                     dset = ppline_grp.create_group(dname)
                     dset.attrs["n_subj"] = len(d1["dataset"].subject_list)
                     dset.attrs["n_sessions"] = d1["dataset"].n_sessions
                     dt = h5py.special_dtype(vlen=str)
                     dset.create_dataset("id", (0, 2), dtype=dt, maxshape=(None, 2))
                     dset.create_dataset(
-                        "data", (0, 3 + n_add_cols), maxshape=(None, 3 + n_add_cols)
+                        "data",
+                        (0, n_cols + n_add_cols),
+                        maxshape=(None, n_cols + n_add_cols),
                     )
                     dset.attrs["channels"] = d1["n_channels"]
                     dset.attrs.create(
                         "columns",
-                        ["score", "time", "samples", *self.additional_columns],
+                        col_names + self.additional_columns,
                         dtype=dt,
                     )
                 dset = ppline_grp[dname]
@@ -151,24 +186,39 @@ class Results:
                             f"Additional columns: {self.additional_columns} "
                             f"were specified in the evaluation, but results"
                             f" contain only these keys: {d.keys()}."
-                        )
+                        ) from None
+                    cols = [d["score"], d["time"], d["n_samples"]]
+                    if _carbonfootprint:
+                        if isinstance(d["carbon_emission"], tuple):
+                            cols.append(*d["carbon_emission"])
+                        else:
+                            cols.append(d["carbon_emission"])
                     dset["data"][-1, :] = np.asarray(
-                        [d["score"], d["time"], d["n_samples"], *add_cols]
+                        [
+                            *cols,
+                            *add_cols,
+                        ]
                     )
 
-    def to_dataframe(self, pipelines=None):
+    def to_dataframe(self, pipelines=None, process_pipeline=None):
         df_list = []
 
         # get the list of pipeline hash
         digests = []
-        if pipelines is not None:
-            digests = [get_digest(pipelines[name]) for name in pipelines]
+        if pipelines is not None and process_pipeline is not None:
+            digests = [
+                get_pipeline_digest(process_pipeline, pipelines[name])
+                for name in pipelines
+            ]
+        elif pipelines is not None or process_pipeline is not None:
+            raise ValueError(
+                "Either both of none of pipelines and process_pipeline must be specified."
+            )
 
-        with h5py.File(self.filepath, "r") as f:
+        with _open_lock_hdf5(self.filepath, "r") as f:
             for digest, p_group in f.items():
-
                 # skip if not in pipeline list
-                if (pipelines is not None) & (digest not in digests):
+                if (pipelines is not None) and (digest not in digests):
                     continue
 
                 name = p_group.attrs["name"]
@@ -183,24 +233,66 @@ class Results:
                     df["dataset"] = dname
                     df["pipeline"] = name
                     df_list.append(df)
+
         return pd.concat(df_list, ignore_index=True)
 
-    def not_yet_computed(self, pipelines, dataset, subj):
-        """Check if a results has already been computed."""
+    def not_yet_computed(self, pipelines, dataset, subj, process_pipeline):
+        """Check if a results is missing.
+
+        Parameters
+        ----------
+        pipelines : dict of pipeline instance.
+            A dict containing the sklearn pipeline to evaluate.
+        dataset : Dataset instance
+            The dataset to check for
+        subj : str
+            The subject to check for
+        process_pipeline : Pipeline | None
+            Optional pipeline to apply to the data after the preprocessing.
+            This pipeline must be "fixed" because it will not be trained,
+            i.e. no call to ``fit`` will be made.
+
+        Returns
+        -------
+        dict
+            A dict containing the pipelines to compute.
+        """
         ret = {
             k: pipelines[k]
             for k in pipelines.keys()
-            if not self._already_computed(pipelines[k], dataset, subj)
+            if not self._already_computed(pipelines[k], dataset, subj, process_pipeline)
         }
         return ret
 
-    def _already_computed(self, pipeline, dataset, subject, session=None):
-        """Check if we have results for a current combination of pipeline
-        / dataset / subject.
+    def _already_computed(
+        self, pipeline, dataset, subject, process_pipeline, session=None
+    ):
+        """Check existing results for pipeline / dataset / subject combination.
+
+        Parameters
+        ----------
+        pipeline : dict of pipeline instance.
+            A dict containing the sklearn pipeline to evaluate.
+        dataset : Dataset instance
+            The dataset to check for
+        subject : str
+            The subject to check for
+        process_pipeline : Pipeline | None
+            Optional pipeline to apply to the data after the preprocessing.
+            This pipeline must be "fixed" because it will not be trained,
+            i.e. no call to ``fit`` will be made.
+        session : str | None
+            Not used, kept for compatibility reason.
+
+        Returns
+        -------
+        bool
+            True if the pipeline has already been computed for the given
+            dataset and subject, False otherwise.
         """
         with h5py.File(self.filepath, "r") as f:
             # get the digest from repr
-            digest = get_digest(pipeline)
+            digest = get_pipeline_digest(process_pipeline, pipeline)
 
             # check if digest present
             if digest not in f.keys():
