@@ -1,6 +1,4 @@
-"""
-Alex Motor imagery dataset.
-"""
+"""Alex Motor imagery dataset."""
 
 from mne.io import Raw
 
@@ -35,7 +33,6 @@ class AlexMI(BaseDataset):
            interface cerveau machine EEG asynchrone (Doctoral dissertation,
            Université de Grenoble).
            https://tel.archives-ouvertes.fr/tel-01196752
-
     """
 
     def __init__(self):
@@ -43,15 +40,15 @@ class AlexMI(BaseDataset):
             subjects=list(range(1, 9)),
             sessions_per_subject=1,
             events=dict(right_hand=2, feet=3, rest=4),
-            code="Alexandre Motor Imagery",
+            code="AlexandreMotorImagery",
             interval=[0, 3],
             paradigm="imagery",
         )
 
     def _get_single_subject_data(self, subject):
-        """return data for a single subject"""
+        """Return data for a single subject."""
         raw = Raw(self.data_path(subject), preload=True, verbose="ERROR")
-        return {"session_0": {"run_0": raw}}
+        return {"0": {"0": raw}}
 
     def data_path(
         self, subject, path=None, force_update=False, update_path=None, verbose=None
@@ -59,4 +56,4 @@ class AlexMI(BaseDataset):
         if subject not in self.subject_list:
             raise (ValueError("Invalid subject number"))
         url = "{:s}subject{:d}.raw.fif".format(ALEX_URL, subject)
-        return dl.data_dl(url, "ALEXEEG", path, force_update, update_path, verbose)
+        return dl.data_dl(url, "ALEXEEG", path, force_update, verbose)
