@@ -1,6 +1,4 @@
-"""
-BBCI EEG fNIRS Motor imagery dataset.
-"""
+"""BBCI EEG fNIRS Motor imagery dataset."""
 
 import os
 import os.path as op
@@ -9,11 +7,13 @@ import zipfile as z
 import numpy as np
 from mne import create_info
 from mne.channels import make_standard_montage
-from mne.datasets.utils import _get_path
 from mne.io import RawArray
-from mne.utils import _fetch_file
+from pooch import retrieve
+from pooch.downloaders import choose_downloader
 from scipy.io import loadmat
 
+from moabb.datasets.download import get_dataset_path
+
 from .base import BaseDataset
 
 
@@ -34,12 +34,17 @@ def eeg_data_path(base_path, subject, accept):
                     if not accept:
                         raise AttributeError(
                             "You must accept licence term to download this dataset,"
-                            "set accept=True when instanciating the dataset."
+                            "set accept=True when instantiating the dataset."
                         )
-                    _fetch_file(
+                    downloader = choose_downloader(SHIN_URL, progressbar=True)
+                    downloader.kwargs.setdefault("verify", False)
+                    retrieve(
                         "{}/EEG/EEG_{:02d}-{:02d}.zip".format(SHIN_URL, low, high),
-                        op.join(base_path, "EEG.zip"),
-                        print_destination=False,
+                        None,
+                        fname="EEG.zip",
+                        path=base_path,
+                        progressbar=True,
+                        downloader=downloader,
                     )
                 with z.ZipFile(op.join(base_path, "EEG.zip"), "r") as f:
                     f.extractall(op.join(base_path, "EEG"))
@@ -57,12 +62,14 @@ def fnirs_data_path(path, subject, accept):
             if not accept:
                 raise AttributeError(
                     "You must accept licence term to download this dataset,"
-                    "set accept=True when instanciating the dataset."
+                    "set accept=True when instantiating the dataset."
                 )
-            _fetch_file(
+            retrieve(
                 "http://doc.ml.tu-berlin.de/hBCI/NIRS/NIRS_01-29.zip",
-                op.join(path, "fNIRS.zip"),
-                print_destination=False,
+                None,
+                fname="fNIRS.zip",
+                path=path,
+                progressbar=True,
             )
         if not op.isdir(op.join(path, "NIRS")):
             os.makedirs(op.join(path, "NIRS"))
@@ -72,11 +79,16 @@ def fnirs_data_path(path, subject, accept):
     return [op.join(datapath, fn) for fn in ["cnt.mat", "mrk.mat"]]
 
 
-class Shin2017(BaseDataset):
+class BaseShin2017(BaseDataset):
     """Not to be used."""
 
     def __init__(
-        self, fnirs=False, motor_imagery=True, mental_arithmetic=False, accept=False
+        self,
+        suffix,
+        fnirs=False,
+        motor_imagery=True,
+        mental_arithmetic=False,
+        accept=False,
     ):
         if not any([motor_imagery, mental_arithmetic]):
             raise (
@@ -85,16 +97,13 @@ class Shin2017(BaseDataset):
                 )
             )
         events = dict()
-        paradigms = []
         n_sessions = 0
         if motor_imagery:
             events.update(dict(left_hand=1, right_hand=2))
-            paradigms.append("imagery")
             n_sessions += 3
 
         if mental_arithmetic:
-            events.update(dict(substraction=3, rest=4))
-            paradigms.append("arithmetic")
+            events.update(dict(subtraction=3, rest=4))
             n_sessions += 3
 
         self.motor_imagery = motor_imagery
@@ -105,10 +114,10 @@ class Shin2017(BaseDataset):
             subjects=list(range(1, 30)),
             sessions_per_subject=n_sessions,
             events=events,
-            code="Shin2017",
+            code="Shin2017" + suffix,
             # marker is for *task* start not cue start
             interval=[0, 10],
-            paradigm=("/").join(paradigms),
+            paradigm="imagery",  # no arithmetic paradigm in MOABB at the moment
             doi="10.1109/TNSRE.2016.2628057",
         )
 
@@ -117,7 +126,7 @@ class Shin2017(BaseDataset):
         self.fnirs = fnirs  # TODO: actually incorporate fNIRS somehow
 
     def _get_single_subject_data(self, subject):
-        """return data for a single subject"""
+        """Return data for a single subject."""
         fname, fname_mrk = self.data_path(subject)
         data = loadmat(fname, squeeze_me=True, struct_as_record=False)["cnt"]
         mrk = loadmat(fname_mrk, squeeze_me=True, struct_as_record=False)["mrk"]
@@ -127,13 +136,13 @@ class Shin2017(BaseDataset):
         if self.motor_imagery:
             for ii in [0, 2, 4]:
                 session = self._convert_one_session(data, mrk, ii, trig_offset=0)
-                sessions["session_%d" % ii] = session
+                sessions[f"{ii}imagery"] = session
 
         # arithmetic/rest
         if self.mental_arithmetic:
             for ii in [1, 3, 5]:
                 session = self._convert_one_session(data, mrk, ii, trig_offset=2)
-                sessions["session_%d" % ii] = session
+                sessions[f"{ii}arithmetic"] = session
 
         return sessions
 
@@ -150,7 +159,7 @@ class Shin2017(BaseDataset):
         info = create_info(ch_names=ch_names, ch_types=ch_types, sfreq=200.0)
         raw = RawArray(data=eeg, info=info, verbose=False)
         raw.set_montage(montage)
-        return {"run_0": raw}
+        return {"0": raw}
 
     def data_path(
         self,
@@ -166,8 +175,7 @@ class Shin2017(BaseDataset):
         if accept:
             self.accept = True
 
-        key = "MNE_DATASETS_BBCIFNIRS_PATH"
-        path = _get_path(path, key, "BBCI EEG-fNIRS")
+        path = get_dataset_path("BBCIFNIRS", path)
         if not op.isdir(op.join(path, "MNE-eegfnirs-data")):
             os.makedirs(op.join(path, "MNE-eegfnirs-data"))
         if self.fnirs:
@@ -178,13 +186,15 @@ class Shin2017(BaseDataset):
             return eeg_data_path(op.join(path, "MNE-eegfnirs-data"), subject, self.accept)
 
 
-class Shin2017A(Shin2017):
-    """Motor Imagey Dataset from Shin et al 2017
+class Shin2017A(BaseShin2017):
+    """Motor Imagey Dataset from Shin et al 2017.
 
     Dataset from [1]_.
 
-    You should accept the licence term [2]_ to download this dataset, using::
-        Shin2017A(accept=True)
+
+    .. caution::
+       You should accept the licence term [2]_ to download this dataset, using:
+       ``Shin2017A(accept=True)``
 
     **Data Acquisition**
 
@@ -275,24 +285,29 @@ class Shin2017A(Shin2017):
            Hwang, H.J. and Müller, K.R., 2017. Open access dataset for EEG+NIRS
            single-trial classification. IEEE Transactions on Neural Systems
            and Rehabilitation Engineering, 25(10), pp.1735-1745.
+
     .. [2] GNU General Public License, Version 3
            `<https://www.gnu.org/licenses/gpl-3.0.txt>`_
     """
 
     def __init__(self, accept=False):
         super().__init__(
-            fnirs=False, motor_imagery=True, mental_arithmetic=False, accept=accept
+            suffix="A",
+            fnirs=False,
+            motor_imagery=True,
+            mental_arithmetic=False,
+            accept=accept,
         )
-        self.code = "Shin2017A"
 
 
-class Shin2017B(Shin2017):
-    """Mental Arithmetic Dataset from Shin et al 2017
+class Shin2017B(BaseShin2017):
+    """Mental Arithmetic Dataset from Shin et al 2017.
 
     Dataset from [1]_.
 
-    You should accept the licence term [2]_ to download this dataset, using::
-        Shin2017A(accept=True)
+    .. caution::
+        You should accept the licence term [2]_ to download this dataset, using:
+        ``Shin2017B(accept=True)``
 
     **Data Acquisition**
 
@@ -377,12 +392,16 @@ class Shin2017B(Shin2017):
            Hwang, H.J. and Müller, K.R., 2017. Open access dataset for EEG+NIRS
            single-trial classification. IEEE Transactions on Neural Systems
            and Rehabilitation Engineering, 25(10), pp.1735-1745.
+
     .. [2] GNU General Public License, Version 3
            `<https://www.gnu.org/licenses/gpl-3.0.txt>`_
     """
 
     def __init__(self, accept=False):
         super().__init__(
-            fnirs=False, motor_imagery=False, mental_arithmetic=True, accept=accept
+            suffix="B",
+            fnirs=False,
+            motor_imagery=False,
+            mental_arithmetic=True,
+            accept=accept,
         )
-        self.code = "Shin2017B"
