@@ -1,9 +1,11 @@
-"""
-BNCI 2014-001 Motor imagery dataset.
-"""
+"""BNCI 2014-001 Motor imagery dataset."""
+
+import io
+import zipfile
+from pathlib import Path
 
 import numpy as np
-from mne import create_info
+from mne import Annotations, create_info
 from mne.channels import make_standard_montage
 from mne.io import RawArray
 from mne.utils import verbose
@@ -11,6 +13,7 @@ from scipy.io import loadmat
 
 from moabb.datasets import download as dl
 from moabb.datasets.base import BaseDataset
+from moabb.utils import depreciated_alias
 
 
 BNCI_URL = "http://bnci-horizon-2020.eu/database/data-sets/"
@@ -21,14 +24,18 @@ def data_path(url, path=None, force_update=False, update_path=None, verbose=None
     return [dl.data_dl(url, "BNCI", path, force_update, verbose)]
 
 
+_map = {"T": "train", "E": "test"}
+
+
 @verbose
 def load_data(
     subject,
-    dataset="001-2014",
+    dataset="BNCI2014-001",
     path=None,
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):  # noqa: D301
     """Get paths to local copies of a BNCI dataset files.
@@ -54,6 +61,9 @@ def load_data(
     update_path : bool | None
         If True, set the MNE_DATASETS_BNCI_PATH in mne-python
         config to the given path. If None, the user is prompted.
+    only_filenames : bool
+        If True, return only the local path of the files without
+        loading the data.
     verbose : bool, str, int, or None
         If not None, override default verbose level (see :func:`mne.verbose`
         and :ref:`Logging documentation <tut_logging>` for more).
@@ -64,36 +74,38 @@ def load_data(
         List of raw instances for each non consecutive recording. Depending
         on the dataset it could be a BCI run or a different recording session.
     event_id: dict
-        dictonary containing events and their code.
+        dictionary containing events and their code.
     """
     dataset_list = {
-        "001-2014": _load_data_001_2014,
-        "002-2014": _load_data_002_2014,
-        "004-2014": _load_data_004_2014,
-        "008-2014": _load_data_008_2014,
-        "009-2014": _load_data_009_2014,
-        "001-2015": _load_data_001_2015,
-        "003-2015": _load_data_003_2015,
-        "004-2015": _load_data_004_2015,
-        "009-2015": _load_data_009_2015,
-        "010-2015": _load_data_010_2015,
-        "012-2015": _load_data_012_2015,
-        "013-2015": _load_data_013_2015,
+        "BNCI2003-004": _load_data_iva_2003,
+        "BNCI2014-001": _load_data_001_2014,
+        "BNCI2014-002": _load_data_002_2014,
+        "BNCI2014-004": _load_data_004_2014,
+        "BNCI2014-008": _load_data_008_2014,
+        "BNCI2014-009": _load_data_009_2014,
+        "BNCI2015-001": _load_data_001_2015,
+        "BNCI2015-003": _load_data_003_2015,
+        "BNCI2015-004": _load_data_004_2015,
+        "BNCI2015-009": _load_data_009_2015,
+        "BNCI2015-010": _load_data_010_2015,
+        "BNCI2015-012": _load_data_012_2015,
+        "BNCI2015-013": _load_data_013_2015,
     }
 
     baseurl_list = {
-        "001-2014": BNCI_URL,
-        "002-2014": BNCI_URL,
-        "001-2015": BNCI_URL,
-        "004-2014": BNCI_URL,
-        "008-2014": BNCI_URL,
-        "009-2014": BNCI_URL,
-        "003-2015": BNCI_URL,
-        "004-2015": BNCI_URL,
-        "009-2015": BBCI_URL,
-        "010-2015": BBCI_URL,
-        "012-2015": BBCI_URL,
-        "013-2015": BNCI_URL,
+        "BNCI2003-004": "https://www.bbci.de/competition/",
+        "BNCI2014-001": BNCI_URL,
+        "BNCI2014-002": BNCI_URL,
+        "BNCI2015-001": BNCI_URL,
+        "BNCI2014-004": BNCI_URL,
+        "BNCI2014-008": BNCI_URL,
+        "BNCI2014-009": BNCI_URL,
+        "BNCI2015-003": BNCI_URL,
+        "BNCI2015-004": BNCI_URL,
+        "BNCI2015-009": BBCI_URL,
+        "BNCI2015-010": BBCI_URL,
+        "BNCI2015-012": BBCI_URL,
+        "BNCI2015-013": BNCI_URL,
     }
 
     if dataset not in dataset_list.keys():
@@ -103,10 +115,67 @@ def load_data(
         )
 
     return dataset_list[dataset](
-        subject, path, force_update, update_path, baseurl_list[dataset], verbose
+        subject,
+        path,
+        force_update,
+        update_path,
+        baseurl_list[dataset],
+        only_filenames,
+        verbose,
     )
 
 
+@verbose
+def _load_data_iva_2003(
+    subject,
+    path=None,
+    force_update=False,
+    update_path=None,
+    base_url=None,
+    only_filenames=False,
+    verbose=None,
+):
+    """Loads data for the BNCI2003-IVa dataset."""
+    # Raises ValueError is subject is not between 1 and 5
+    if (subject < 1) or (subject > 5):
+        raise ValueError(f"Subject must be between 1 and 5. Got {subject}")
+
+    subject_names = ["aa", "al", "av", "aw", "ay"]
+
+    # fmt: off
+    ch_names = ['Fp1', 'AFp1', 'Fpz', 'AFp2', 'Fp2', 'AF7', 'AF3',
+                'AF4', 'AF8', 'FAF5', 'FAF1', 'FAF2', 'FAF6', 'F7',
+                'F5', 'F3', 'F1', 'Fz', 'F2', 'F4', 'F6', 'F8', 'FFC7',
+                'FFC5', 'FFC3', 'FFC1', 'FFC2', 'FFC4', 'FFC6', 'FFC8',
+                'FT9', 'FT7', 'FC5', 'FC3', 'FC1', 'FCz', 'FC2', 'FC4',
+                'FC6', 'FT8', 'FT10', 'CFC7', 'CFC5', 'CFC3', 'CFC1',
+                'CFC2', 'CFC4', 'CFC6', 'CFC8', 'T7', 'C5', 'C3', 'C1',
+                'Cz','C2', 'C4', 'C6', 'T8', 'CCP7', 'CCP5', 'CCP3', 'CCP1',
+                'CCP2', 'CCP4', 'CCP6', 'CCP8', 'TP9', 'TP7', 'CP5', 'CP3',
+                'CP1', 'CPz', 'CP2', 'CP4', 'CP6', 'TP8', 'TP10', 'PCP7',
+                'PCP5', 'PCP3', 'PCP1', 'PCP2', 'PCP4', 'PCP6', 'PCP8', 'P9',
+                'P7', 'P5', 'P3', 'P1', 'Pz', 'P2', 'P4', 'P6', 'P8', 'P10',
+                'PPO7', 'PPO5', 'PPO1', 'PPO2', 'PPO6', 'PPO8', 'PO7', 'PO3',
+                'PO1', 'POz', 'PO2', 'PO4', 'PO8', 'OPO1', 'OPO2', 'O1',
+                'Oz', 'O2', 'OI1', 'OI2', 'I1', 'I2']
+    # fmt: on
+    ch_type = ["eeg"] * 118
+
+    url = "{u}download/competition_iii/berlin/100Hz/data_set_IVa_{r}_mat.zip".format(
+        u=base_url, r=subject_names[subject - 1]
+    )
+
+    filename = data_path(url, path, force_update, update_path)
+
+    if only_filenames:
+        return filename
+
+    runs, ev = _convert_bbci2003(filename[0], ch_names, ch_type)
+
+    session = {"0train": {"0": runs}}
+    return session
+
+
 @verbose
 def _load_data_001_2014(
     subject,
@@ -114,6 +183,7 @@ def _load_data_001_2014(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 001-2014 dataset."""
@@ -130,12 +200,20 @@ def _load_data_001_2014(
     ch_types = ["eeg"] * 22 + ["eog"] * 3
 
     sessions = {}
-    for r in ["T", "E"]:
+    filenames = []
+    for session_idx, r in enumerate(["T", "E"]):
         url = "{u}001-2014/A{s:02d}{r}.mat".format(u=base_url, s=subject, r=r)
         filename = data_path(url, path, force_update, update_path)
+        filenames += filename
+        if only_filenames:
+            continue
         runs, ev = _convert_mi(filename[0], ch_names, ch_types)
         # FIXME: deal with run with no event (1:3) and name them
-        sessions["session_%s" % r] = {"run_%d" % ii: run for ii, run in enumerate(runs)}
+        sessions[f"{session_idx}{_map[r]}"] = {
+            str(ii): run for ii, run in enumerate(runs)
+        }
+    if only_filenames:
+        return filenames
     return sessions
 
 
@@ -146,6 +224,7 @@ def _load_data_002_2014(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 002-2014 dataset."""
@@ -153,16 +232,20 @@ def _load_data_002_2014(
         raise ValueError("Subject must be between 1 and 14. Got %d." % subject)
 
     runs = []
+    filenames = []
     for r in ["T", "E"]:
         url = "{u}002-2014/S{s:02d}{r}.mat".format(u=base_url, s=subject, r=r)
         filename = data_path(url, path, force_update, update_path)[0]
-
+        filenames.append(filename)
+        if only_filenames:
+            continue
         # FIXME: electrode position and name are not provided directly.
         raws, _ = _convert_mi(filename, None, ["eeg"] * 15)
-        runs.extend(raws)
-
-    runs = {"run_%d" % ii: run for ii, run in enumerate(runs)}
-    return {"session_0": runs}
+        runs.extend(zip([r] * len(raws), raws))
+    if only_filenames:
+        return filenames
+    runs = {f"{ii}{_map[r]}": run for ii, (r, run) in enumerate(runs)}
+    return {"0": runs}
 
 
 @verbose
@@ -172,6 +255,7 @@ def _load_data_004_2014(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 004-2014 dataset."""
@@ -182,13 +266,19 @@ def _load_data_004_2014(
     ch_types = ["eeg"] * 3 + ["eog"] * 3
 
     sessions = []
+    filenames = []
     for r in ["T", "E"]:
         url = "{u}004-2014/B{s:02d}{r}.mat".format(u=base_url, s=subject, r=r)
         filename = data_path(url, path, force_update, update_path)[0]
+        filenames.append(filename)
+        if only_filenames:
+            continue
         raws, _ = _convert_mi(filename, ch_names, ch_types)
-        sessions.extend(raws)
+        sessions.extend(zip([r] * len(raws), raws))
 
-    sessions = {"session_%d" % ii: {"run_0": run} for ii, run in enumerate(sessions)}
+    if only_filenames:
+        return filenames
+    sessions = {f"{ii}{_map[r]}": {"0": run} for ii, (r, run) in enumerate(sessions)}
     return sessions
 
 
@@ -199,6 +289,7 @@ def _load_data_008_2014(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 008-2014 dataset."""
@@ -207,11 +298,12 @@ def _load_data_008_2014(
 
     url = "{u}008-2014/A{s:02d}.mat".format(u=base_url, s=subject)
     filename = data_path(url, path, force_update, update_path)[0]
-
+    if only_filenames:
+        return [filename]
     run = loadmat(filename, struct_as_record=False, squeeze_me=True)["data"]
     raw, event_id = _convert_run_p300_sl(run, verbose=verbose)
 
-    sessions = {"session_0": {"run_0": raw}}
+    sessions = {"0": {"0": raw}}
 
     return sessions
 
@@ -223,6 +315,7 @@ def _load_data_009_2014(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 009-2014 dataset."""
@@ -233,18 +326,23 @@ def _load_data_009_2014(
     # we load only grid speller data
     url = "{u}009-2014/A{s:02d}S.mat".format(u=base_url, s=subject)
     filename = data_path(url, path, force_update, update_path)[0]
+    if only_filenames:
+        return [filename]
 
     data = loadmat(filename, struct_as_record=False, squeeze_me=True)["data"]
     sess = []
     event_id = {}
     for run in data:
         raw, ev = _convert_run_p300_sl(run, verbose=verbose)
+        # Raw EEG data are scaled by a factor 10.
+        # See https://github.com/NeuroTechX/moabb/issues/275
+        raw._data[:16, :] /= 10.0
         sess.append(raw)
         event_id.update(ev)
 
     sessions = {}
     for i, sessi in enumerate(sess):
-        sessions["session_" + str(i)] = {"run_0": sessi}
+        sessions[str(i)] = {"0": sessi}
 
     return sessions
 
@@ -256,6 +354,7 @@ def _load_data_001_2015(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 001-2015 dataset."""
@@ -263,9 +362,9 @@ def _load_data_001_2015(
         raise ValueError("Subject must be between 1 and 12. Got %d." % subject)
 
     if subject in [8, 9, 10, 11]:
-        ses = ["A", "B", "C"]  # 3 sessions for those subjects
+        ses = [(0, "A"), (1, "B"), (2, "C")]  # 3 sessions for those subjects
     else:
-        ses = ["A", "B"]
+        ses = [(0, "A"), (1, "B")]
 
     # fmt: off
     ch_names = [
@@ -276,11 +375,17 @@ def _load_data_001_2015(
     ch_types = ["eeg"] * 13
 
     sessions = {}
-    for r in ses:
+    filenames = []
+    for session_idx, r in ses:
         url = "{u}001-2015/S{s:02d}{r}.mat".format(u=base_url, s=subject, r=r)
         filename = data_path(url, path, force_update, update_path)
+        filenames += filename
+        if only_filenames:
+            continue
         runs, ev = _convert_mi(filename[0], ch_names, ch_types)
-        sessions["session_%s" % r] = {"run_%d" % ii: run for ii, run in enumerate(runs)}
+        sessions[f"{session_idx}{r}"] = {str(ii): run for ii, run in enumerate(runs)}
+    if only_filenames:
+        return filenames
     return sessions
 
 
@@ -291,6 +396,7 @@ def _load_data_003_2015(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 003-2015 dataset."""
@@ -299,6 +405,8 @@ def _load_data_003_2015(
 
     url = "{u}003-2015/s{s:d}.mat".format(u=base_url, s=subject)
     filename = data_path(url, path, force_update, update_path)[0]
+    if only_filenames:
+        return [filename]
 
     data = loadmat(filename, struct_as_record=False, squeeze_me=True)
     data = data["s%d" % subject]
@@ -312,12 +420,12 @@ def _load_data_003_2015(
     info = create_info(ch_names=ch_names, ch_types=ch_types, sfreq=sfreq)
 
     sessions = {}
-    sessions["session_0"] = {}
-    for ri, run in enumerate([data.train, data.test]):
+    sessions["0"] = {}
+    for r_name, run in [("0train", data.train), ("1test", data.test)]:
         # flash events on the channel 9
         flashs = run[9:10]
         ix_flash = flashs[0] > 0
-        flashs[0, ix_flash] += 2  # add 2 to avoid overlapp on event id
+        flashs[0, ix_flash] += 2  # add 2 to avoid overlap on event id
         flash_code = np.unique(flashs[0, ix_flash])
 
         if len(flash_code) == 36:
@@ -335,7 +443,7 @@ def _load_data_003_2015(
         eeg_data = np.r_[run[1:-2] * 1e-6, targets, flashs]
         raw = RawArray(data=eeg_data, info=info, verbose=verbose)
         raw.set_montage(montage)
-        sessions["session_0"]["run_" + str(ri)] = raw
+        sessions["0"][r_name] = raw
 
     return sessions
 
@@ -347,6 +455,7 @@ def _load_data_004_2015(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 004-2015 dataset."""
@@ -357,6 +466,8 @@ def _load_data_004_2015(
 
     url = "{u}004-2015/{s}.mat".format(u=base_url, s=subjects[subject - 1])
     filename = data_path(url, path, force_update, update_path)[0]
+    if only_filenames:
+        return [filename]
 
     # fmt: off
     ch_names = [
@@ -367,7 +478,7 @@ def _load_data_004_2015(
     # fmt: on
     ch_types = ["eeg"] * 30
     raws, ev = _convert_mi(filename, ch_names, ch_types)
-    sessions = {"session_%d" % ii: {"run_0": run} for ii, run in enumerate(raws)}
+    sessions = {str(ii): {"0": run} for ii, run in enumerate(raws)}
     return sessions
 
 
@@ -378,6 +489,7 @@ def _load_data_009_2015(
     force_update=False,
     update_path=None,
     base_url=BBCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 009-2015 dataset."""
@@ -393,6 +505,8 @@ def _load_data_009_2015(
     s = subjects[subject - 1]
     url = "{u}BNCIHorizon2020-AMUSE/AMUSE_VP{s}.mat".format(u=base_url, s=s)
     filename = data_path(url, path, force_update, update_path)[0]
+    if only_filenames:
+        return [filename]
 
     ch_types = ["eeg"] * 60 + ["eog"] * 2
 
@@ -406,6 +520,7 @@ def _load_data_010_2015(
     force_update=False,
     update_path=None,
     base_url=BBCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 010-2015 dataset."""
@@ -422,6 +537,8 @@ def _load_data_010_2015(
     s = subjects[subject - 1]
     url = "{u}BNCIHorizon2020-RSVP/RSVP_VP{s}.mat".format(u=base_url, s=s)
     filename = data_path(url, path, force_update, update_path)[0]
+    if only_filenames:
+        return [filename]
 
     ch_types = ["eeg"] * 63
 
@@ -435,6 +552,7 @@ def _load_data_012_2015(
     force_update=False,
     update_path=None,
     base_url=BBCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 012-2015 dataset."""
@@ -446,6 +564,8 @@ def _load_data_012_2015(
     s = subjects[subject - 1]
     url = "{u}BNCIHorizon2020-PASS2D/PASS2D_VP{s}.mat".format(u=base_url, s=s)
     filename = data_path(url, path, force_update, update_path)[0]
+    if only_filenames:
+        return [filename]
 
     ch_types = ["eeg"] * 63
 
@@ -459,6 +579,7 @@ def _load_data_013_2015(
     force_update=False,
     update_path=None,
     base_url=BNCI_URL,
+    only_filenames=False,
     verbose=None,
 ):
     """Load data for 013-2015 dataset."""
@@ -469,6 +590,8 @@ def _load_data_013_2015(
     for r in ["s1", "s2"]:
         url = "{u}013-2015/Subject{s:02d}_{r}.mat".format(u=base_url, s=subject, r=r)
         data_paths.extend(data_path(url, path, force_update, update_path))
+    if only_filenames:
+        return data_paths
 
     raws = []
     event_id = {}
@@ -483,10 +606,21 @@ def _load_data_013_2015(
 
 
 def _convert_mi(filename, ch_names, ch_types):
-    """
-    Processes (Graz) motor imagery data from MAT files, returns list of
-    recording runs.
-    """
+    """Process (Graz) motor imagery data from MAT files.
+
+    Parameters
+    ----------
+    filename : str
+        Path to the MAT file.
+    ch_names : list of str
+        List of channel names.
+    ch_types : list of str
+        List of channel types.
+
+    Returns
+    -------
+    raw : instance of RawArray
+        returns list of recording runs."""
     runs = []
     event_id = {}
     data = loadmat(filename, struct_as_record=False, squeeze_me=True)
@@ -621,6 +755,102 @@ def _convert_run_bbci(run, ch_types, verbose=None):
     return raw, event_id
 
 
+def _convert_bbci2003(filename, ch_names, ch_type):
+    """
+    Process motor imagery data from MAT files.
+
+     Parameters
+     ----------
+        filename (str):
+            Path to the MAT file.
+        ch_names (list of str):
+            List of channel names.
+        ch_type (list of str):
+            List of channel types.
+
+    Returns
+    -------
+        raw (instance of RawArray):
+            returns MNE Raw object.
+    """
+    zip_path = Path(filename)
+
+    with zipfile.ZipFile(zip_path, "r") as z:
+        mat_files = [f for f in z.namelist() if f.endswith(".mat")]
+
+        if not mat_files:
+            raise FileNotFoundError("No .mat file found in zip archive.")
+
+        with z.open(mat_files[0]) as f:
+            data = loadmat(io.BytesIO(f.read()))
+
+        run = data
+        raw, ev = _convert_run_bbci2003(run, ch_names, ch_type)
+        return raw, ev
+
+
+@verbose
+def _convert_run_bbci2003(run, ch_names, ch_types, verbose=None):
+    """
+    Converts one run to a raw MNE object.
+
+    Parameters
+    ----------
+        run (ndarray):
+            The continuous EEG signal.
+        ch_names (list of str):
+            List of channel names.
+        ch_types (list of str):
+            List of channel types.
+        verbose (bool, str, int, or None):
+            If not None, override default verbose level (see :func:`mne.verbose`
+            and :ref:`Logging documentation <tut_logging>` for more).
+
+    Returns:
+        raw (instance of RawArray):
+            MNE Raw object.
+        event_id (dict):
+            Dictionary containing class names.
+    """
+    class_map = {
+        "right": "right_hand",
+        "foot": "feet",
+    }
+
+    raw_labels = run["mrk"]["y"][0, 0][0]
+    labels_mask = ~np.isnan(raw_labels)
+    valid_labels = raw_labels[labels_mask]
+    labels = valid_labels.astype(int) - 1
+
+    raw_positions = run["mrk"][0][0]["pos"][0]
+    positions = raw_positions[labels_mask]
+
+    sfreq = float(run["nfo"][0, 0]["fs"][0, 0])
+    eeg_data = run["cnt"]
+    raw_classes = run["mrk"]["className"]
+
+    while isinstance(raw_classes, (list, np.ndarray)) and len(raw_classes) == 1:
+        raw_classes = raw_classes[0]
+    class_names = [cls[0] for cls in raw_classes]
+
+    for i, word in enumerate(class_names):
+        if word in class_map:
+            class_names[i] = class_map[word]
+
+    info = create_info(ch_names=ch_names, ch_types=ch_types, sfreq=sfreq)
+
+    onset = positions / sfreq
+    duration = 0
+    description = [class_names[i] for i in labels]
+    annotations = Annotations(onset=onset, duration=duration, description=description)
+
+    event_id = {name: i for i, name in enumerate(class_names)}
+    raw = RawArray(data=eeg_data.T, info=info, verbose=verbose)
+    raw.set_annotations(annotations)
+
+    return raw, event_id
+
+
 @verbose
 def _convert_run_epfl(run, verbose=None):
     """Convert one run to raw."""
@@ -654,10 +884,10 @@ def _convert_run_epfl(run, verbose=None):
 
 
 class MNEBNCI(BaseDataset):
-    """Base BNCI dataset"""
+    """Base BNCI dataset."""
 
     def _get_single_subject_data(self, subject):
-        """return data for a single subject"""
+        """Return data for a single subject."""
         sessions = load_data(subject=subject, dataset=self.code, verbose=False)
         return sessions
 
@@ -671,10 +901,57 @@ class MNEBNCI(BaseDataset):
             update_path=update_path,
             path=path,
             force_update=force_update,
+            only_filenames=True,
         )
 
 
-class BNCI2014001(MNEBNCI):
+class BNCI2003_004(MNEBNCI):
+    """
+    BNCI2003_IVa Motor Imagery dataset.
+
+    Dataset IVa from BCI Competition III [1]_.
+
+    **Dataset Description**
+
+    This data set was recorded from five healthy subjects. Subjects sat in
+    a comfortable chair with arms resting on armrests. This data set
+    contains only data from the 4 initial sessions without feedback.
+    Visual cues indicated for 3.5 s which of the following 3 motor
+    imageries the subject should perform: (L) left hand, (R) right hand,
+    (F) right foot. The presentation of target cues were intermitted by
+    periods of random length, 1.75 to 2.25 s, in which the subject could
+    relax.
+
+    There were two types of visual stimulation: (1) where targets were
+    indicated by letters appearing behind a fixation cross (which might
+    nevertheless induce little target-correlated eye movements), and (2)
+    where a randomly moving object indicated targets (inducing target-
+    uncorrelated eye movements). From subjects al and aw 2 sessions of
+    both types were recorded, while from the other subjects 3 sessions
+    of type (2) and 1 session of type (1) were recorded.
+
+    References
+    ----------
+    .. [1] Guido Dornhege, Benjamin Blankertz, Gabriel Curio, and Klaus-Robert
+           Müller. Boosting bit rates in non-invasive EEG single-trial
+           classifications by feature combination and multi-class paradigms.
+           IEEE Trans. Biomed. Eng., 51(6):993-1002, June 2004.
+    """
+
+    def __init__(self):
+        super().__init__(
+            subjects=list(range(1, 6)),
+            sessions_per_subject=1,
+            events={"right_hand": 0, "feet": 1},
+            code="BNCI2003-004",
+            interval=[0, 3.5],
+            paradigm="imagery",
+            doi="10.1109/TBME.2004.827088",
+        )
+
+
+@depreciated_alias("BNCI2014001", "1.1")
+class BNCI2014_001(MNEBNCI):
     """BNCI 2014-001 Motor Imagery dataset.
 
     Dataset IIa from BCI Competition 4 [1]_.
@@ -710,7 +987,6 @@ class BNCI2014001(MNEBNCI):
 
     References
     ----------
-
     .. [1] Tangermann, M., Müller, K.R., Aertsen, A., Birbaumer, N., Braun, C.,
            Brunner, C., Leeb, R., Mehring, C., Miller, K.J., Mueller-Putz, G.
            and Nolte, G., 2012. Review of the BCI competition IV.
@@ -722,14 +998,15 @@ class BNCI2014001(MNEBNCI):
             subjects=list(range(1, 10)),
             sessions_per_subject=2,
             events={"left_hand": 1, "right_hand": 2, "feet": 3, "tongue": 4},
-            code="001-2014",
+            code="BNCI2014-001",
             interval=[2, 6],
             paradigm="imagery",
             doi="10.3389/fnins.2012.00055",
         )
 
 
-class BNCI2014002(MNEBNCI):
+@depreciated_alias("BNCI2014002", "1.1")
+class BNCI2014_002(MNEBNCI):
     """BNCI 2014-002 Motor Imagery dataset.
 
     Motor Imagery Dataset from [1]_.
@@ -762,13 +1039,11 @@ class BNCI2014002(MNEBNCI):
     medical or neurological diseases.
 
     References
-    -----------
-
+    ----------
     .. [1] Steyrl, D., Scherer, R., Faller, J. and Müller-Putz, G.R., 2016.
            Random forests in non-invasive sensorimotor rhythm brain-computer
            interfaces: a practical and convenient non-linear classifier.
-           Biomedical Engineering/Biomedizinische Technik, 61(1), pp.77-86.
-
+           Biomedical Engineering/Biomedizinische Technique, 61(1), pp.77-86.
     """
 
     def __init__(self):
@@ -776,14 +1051,15 @@ class BNCI2014002(MNEBNCI):
             subjects=list(range(1, 15)),
             sessions_per_subject=1,
             events={"right_hand": 1, "feet": 2},
-            code="002-2014",
+            code="BNCI2014-002",
             interval=[3, 8],
             paradigm="imagery",
             doi="10.1515/bmt-2014-0117",
         )
 
 
-class BNCI2014004(MNEBNCI):
+@depreciated_alias("BNCI2014004", "1.1")
+class BNCI2014_004(MNEBNCI):
     """BNCI 2014-004 Motor Imagery dataset.
 
     Dataset B from BCI Competition 2008.
@@ -842,7 +1118,6 @@ class BNCI2014004(MNEBNCI):
            G. Pfurtscheller. Brain-computer communication: motivation, aim,
            and impact of exploring a virtual apartment. IEEE Transactions on
            Neural Systems and Rehabilitation Engineering 15, 473–482, 2007
-
     """
 
     def __init__(self):
@@ -850,15 +1125,16 @@ class BNCI2014004(MNEBNCI):
             subjects=list(range(1, 10)),
             sessions_per_subject=5,
             events={"left_hand": 1, "right_hand": 2},
-            code="004-2014",
+            code="BNCI2014-004",
             interval=[3, 7.5],
             paradigm="imagery",
             doi="10.1109/TNSRE.2007.906956",
         )
 
 
-class BNCI2014008(MNEBNCI):
-    """BNCI 2014-008 P300 dataset
+@depreciated_alias("BNCI2014008", "1.1")
+class BNCI2014_008(MNEBNCI):
+    """BNCI 2014-008 P300 dataset.
 
     Dataset from [1]_.
 
@@ -866,7 +1142,7 @@ class BNCI2014008(MNEBNCI):
 
     This dataset represents a complete record of P300 evoked potentials
     using a paradigm originally described by Farwell and Donchin [2]_.
-    In these sessions, 8 users with amyotrophic lateral sclerosis (ALS)
+    In these sessions, 8 users with amyotrophic lateral sclerosis (ALSO)
     focused on one out of 36 different characters. The objective in this
     contest is to predict the correct character in each of the provided
     character selection epochs.
@@ -904,7 +1180,6 @@ class BNCI2014008(MNEBNCI):
            toward a mental prosthesis utilizing eventrelated
            brain potentials, Electroencephalogr. Clin. Neurophysiol.,
            vol. 70, n. 6, pagg. 510–523, 1988.
-
     """
 
     def __init__(self):
@@ -912,14 +1187,15 @@ class BNCI2014008(MNEBNCI):
             subjects=list(range(1, 9)),
             sessions_per_subject=1,
             events={"Target": 2, "NonTarget": 1},
-            code="008-2014",
+            code="BNCI2014-008",
             interval=[0, 1.0],
             paradigm="p300",
             doi="10.3389/fnhum.2013.00732",
         )
 
 
-class BNCI2014009(MNEBNCI):
+@depreciated_alias("BNCI2014009", "1.1")
+class BNCI2014_009(MNEBNCI):
     """BNCI 2014-009 P300 dataset.
 
     Dataset from [1]_.
@@ -928,7 +1204,7 @@ class BNCI2014009(MNEBNCI):
 
     This dataset presents a complete record of P300 evoked potentials
     using two different paradigms: a paradigm based on the P300 Speller in
-    overt attention condition and a paradigm based used in covert attention
+    overt attention condition and a paradigm based used in convert attention
     condition. In these sessions, 10 healthy subjects focused on one out of 36
     different characters. The objective was to predict the correct character
     in each of the provided character selection epochs.
@@ -953,12 +1229,10 @@ class BNCI2014009(MNEBNCI):
 
     References
     ----------
-
     .. [1] P Aricò, F Aloise, F Schettini, S Salinari, D Mattia and F Cincotti
            (2013). Influence of P300 latency jitter on event related potential-
            based brain–computer interface performance. Journal of Neural
            Engineering, vol. 11, number 3.
-
     """
 
     def __init__(self):
@@ -966,14 +1240,15 @@ class BNCI2014009(MNEBNCI):
             subjects=list(range(1, 11)),
             sessions_per_subject=3,
             events={"Target": 2, "NonTarget": 1},
-            code="009-2014",
+            code="BNCI2014-009",
             interval=[0, 0.8],
             paradigm="p300",
             doi="10.1088/1741-2560/11/3/035008",
         )
 
 
-class BNCI2015001(MNEBNCI):
+@depreciated_alias("BNCI2015001", "1.1")
+class BNCI2015_001(MNEBNCI):
     """BNCI 2015-001 Motor Imagery dataset.
 
     Dataset from [1]_.
@@ -992,7 +1267,7 @@ class BNCI2015001(MNEBNCI):
 
     The task for the user was to perform sustained right hand versus both feet
     movement imagery starting from the cue (second 3) to the end of the cross
-    period (sec- ond 8).  A trial started with 3 s of reference period,
+    period (sec- and 8).  A trial started with 3 s of reference period,
     followed by a brisk audible cue and a visual cue (arrow right for right
     hand, arrow down for both feet) from second 3 to 4.25.
     The activity period, where the users received feedback, lasted from
@@ -1000,12 +1275,10 @@ class BNCI2015001(MNEBNCI):
 
     References
     ----------
-
     .. [1] J. Faller, C. Vidaurre, T. Solis-Escalante, C. Neuper and R.
            Scherer (2012). Autocalibration and recurrent adaptation: Towards a
            plug and play online ERD- BCI.  IEEE Transactions on Neural Systems
            and Rehabilitation Engineering, 20(3), 313-319.
-
     """
 
     def __init__(self):
@@ -1014,16 +1287,18 @@ class BNCI2015001(MNEBNCI):
             subjects=list(range(1, 13)),
             sessions_per_subject=2,
             events={"right_hand": 1, "feet": 2},
-            code="001-2015",
+            code="BNCI2015-001",
             interval=[0, 5],
             paradigm="imagery",
             doi="10.1109/tnsre.2012.2189584",
         )
 
 
-class BNCI2015003(MNEBNCI):
+@depreciated_alias("BNCI2015003", "1.1")
+class BNCI2015_003(MNEBNCI):
     """BNCI 2015-003 P300 dataset.
 
+
     Dataset from [1]_.
 
     **Dataset description**
@@ -1036,12 +1311,10 @@ class BNCI2015003(MNEBNCI):
 
     References
     ----------
-
     .. [1]  C. Guger, S. Daban, E. Sellers, C. Holzner, G. Krausz,
             R. Carabalona, F. Gramatica, and G. Edlinger (2009). How many
             people are able to control a P300-based brain-computer interface
             (BCI)?. Neuroscience Letters, vol. 462, pp. 94–98.
-
     """
 
     def __init__(self):
@@ -1049,14 +1322,15 @@ class BNCI2015003(MNEBNCI):
             subjects=list(range(1, 11)),
             sessions_per_subject=1,
             events={"Target": 2, "NonTarget": 1},
-            code="003-2015",
+            code="BNCI2015-003",
             interval=[0, 0.8],
             paradigm="p300",
             doi="10.1016/j.neulet.2009.06.045",
         )
 
 
-class BNCI2015004(MNEBNCI):
+@depreciated_alias("BNCI2015004", "1.1")
+class BNCI2015_004(MNEBNCI):
     """BNCI 2015-004 Motor Imagery dataset.
 
     Dataset from [1]_.
@@ -1082,7 +1356,7 @@ class BNCI2015004(MNEBNCI):
     ground were placed at the left and right mastoid, respectively.  The g.tec
     GAMMAsys system with g.LADYbird active electrodes and two g.USBamp
     biosignal
-    amplifiers (Guger Technolgies, Graz, Austria) was used for recording.  EEG
+    amplifiers (Guger Technologies, Graz, Austria) was used for recording.  EEG
     was band pass filtered 0.5-100 Hz (notch filter at 50 Hz) and sampled at a
     rate of 256 Hz.
 
@@ -1102,12 +1376,10 @@ class BNCI2015004(MNEBNCI):
 
     References
     ----------
-
     .. [1] Scherer R, Faller J, Friedrich EVC, Opisso E, Costa U, Kübler A, et
            al. (2015) Individually Adapted Imagery Improves Brain-Computer
            Interface Performance in End-Users with Disability. PLoS ONE 10(5).
            https://doi.org/10.1371/journal.pone.0123727
-
     """
 
     def __init__(self):
@@ -1115,7 +1387,7 @@ class BNCI2015004(MNEBNCI):
             subjects=list(range(1, 10)),
             sessions_per_subject=2,
             events=dict(right_hand=4, feet=5, navigation=3, subtraction=2, word_ass=1),
-            code="004-2015",
+            code="BNCI2015-004",
             interval=[3, 10],
             paradigm="imagery",
             doi="10.1371/journal.pone.0123727",
