@@ -1,18 +1,19 @@
-"""
-Munich MI dataset
-"""
+"""Munich MI dataset."""
 
 import mne
 import numpy as np
 
 from moabb.datasets import download as dl
 from moabb.datasets.base import BaseDataset
+from moabb.datasets.utils import stim_channels_with_selected_ids
+from moabb.utils import depreciated_alias
 
 
 DOWNLOAD_URL = "https://zenodo.org/record/1217449/files/"
 
 
-class MunichMI(BaseDataset):
+@depreciated_alias("MunichMI", "1.1")
+class GrosseWentrup2009(BaseDataset):
     """Munich Motor Imagery dataset.
 
     Motor imagery dataset from Grosse-Wentrup et al. 2009 [1]_.
@@ -53,22 +54,22 @@ class MunichMI(BaseDataset):
     .. [1] Grosse-Wentrup, Moritz, et al. "Beamforming in noninvasive
            brain–computer interfaces." IEEE Transactions on Biomedical
            Engineering 56.4 (2009): 1209-1219.
-
     """
 
     def __init__(self):
+        self.events_id = dict(right_hand=2, left_hand=1)
         super().__init__(
             subjects=list(range(1, 11)),
             sessions_per_subject=1,
-            events=dict(right_hand=2, left_hand=1),
-            code="Grosse-Wentrup 2009",
+            events=self.events_id,
+            code="GrosseWentrup2009",
             interval=[0, 7],
             paradigm="imagery",
             doi="10.1109/TBME.2008.2009768",
         )
 
     def _get_single_subject_data(self, subject):
-        """return data for a single subject"""
+        """Return data for a single subject."""
         raw = mne.io.read_raw_eeglab(
             self.data_path(subject), preload=True, verbose="ERROR"
         )
@@ -77,7 +78,7 @@ class MunichMI(BaseDataset):
         stim[stim == "20"] = "right_hand"
         stim[stim == "10"] = "left_hand"
         raw.annotations.description = stim
-        return {"session_0": {"run_0": raw}}
+        return {"0": {"0": stim_channels_with_selected_ids(raw, self.event_id)}}
 
     def data_path(
         self, subject, path=None, force_update=False, update_path=None, verbose=None
@@ -87,8 +88,8 @@ class MunichMI(BaseDataset):
 
         # download .set
         _set = "{:s}subject{:d}.set".format(DOWNLOAD_URL, subject)
-        set_local = dl.data_dl(_set, "MUNICHMI", path, force_update, update_path, verbose)
+        set_local = dl.data_dl(_set, "MUNICHMI", path, force_update, verbose)
         # download .fdt
         _fdt = "{:s}subject{:d}.fdt".format(DOWNLOAD_URL, subject)
-        dl.data_dl(_fdt, "MUNICHMI", path, force_update, update_path, verbose)
+        dl.data_dl(_fdt, "MUNICHMI", path, force_update, verbose)
         return set_local
