@@ -1,17 +1,15 @@
-"""
-Physionet Motor imagery dataset.
-"""
+"""Physionet Motor imagery dataset."""
 
 import mne
 import numpy as np
-from mne.datasets import eegbci
 from mne.io import read_raw_edf
 
 from moabb.datasets.base import BaseDataset
-from moabb.datasets.download import get_dataset_path
+from moabb.datasets.download import data_dl, get_dataset_path
+from moabb.datasets.utils import stim_channels_with_selected_ids
 
 
-BASE_URL = "http://archive.physionet.org/pn4/eegmmidb/"
+BASE_URL = "https://physionet.org/files/eegmmidb/1.0.0/"
 
 
 class PhysionetMI(BaseDataset):
@@ -75,14 +73,16 @@ class PhysionetMI(BaseDataset):
             subjects=list(range(1, 110)),
             sessions_per_subject=1,
             events=dict(left_hand=2, right_hand=3, feet=5, hands=4, rest=1),
-            code="Physionet Motor Imagery",
+            code="PhysionetMotorImagery",
             # website does not specify how long the trials are, but the
             # interval between 2 trial is 4 second.
             interval=[0, 3],
             paradigm="imagery",
             doi="10.1109/TBME.2004.827072",
         )
-
+        self.events = dict(left_hand=2, right_hand=3, feet=5, hands=4, rest=1)
+        self.imagined = imagined
+        self.executed = executed
         self.feet_runs = []
         self.hand_runs = []
 
@@ -95,9 +95,7 @@ class PhysionetMI(BaseDataset):
             self.hand_runs += [3, 7, 11]
 
     def _load_one_run(self, subject, run, preload=True):
-        raw_fname = eegbci.load_data(
-            subject, runs=[run], verbose="ERROR", base_url=BASE_URL
-        )[0]
+        raw_fname = self._load_data(subject, runs=[run], verbose="ERROR")[0]
         raw = read_raw_edf(raw_fname, preload=preload, verbose="ERROR")
         raw.rename_channels(lambda x: x.strip("."))
         raw.rename_channels(lambda x: x.upper())
@@ -112,12 +110,13 @@ class PhysionetMI(BaseDataset):
         return raw
 
     def _get_single_subject_data(self, subject):
-        """return data for a single subject"""
+        """Return data for a single subject."""
         data = {}
         sign = "EEGBCI"
         get_dataset_path(sign, None)
 
         # hand runs
+        idx = 0
         for run in self.hand_runs:
             raw = self._load_one_run(subject, run)
             stim = raw.annotations.description.astype(np.dtype("<U10"))
@@ -125,31 +124,55 @@ class PhysionetMI(BaseDataset):
             stim[stim == "T1"] = "left_hand"
             stim[stim == "T2"] = "right_hand"
             raw.annotations.description = stim
-            data["run_%d" % run] = raw
+            data[str(idx)] = stim_channels_with_selected_ids(
+                raw, desired_event_id=self.events
+            )
+            idx += 1
 
         # feet runs
         for run in self.feet_runs:
             raw = self._load_one_run(subject, run)
-            # modify stim channels to match new event ids. for feets runs,
+            # modify stim channels to match new event ids. for feet runs,
             # hand = 2 modified to 4, and feet = 3, modified to 5
             stim = raw.annotations.description.astype(np.dtype("<U10"))
             stim[stim == "T0"] = "rest"
             stim[stim == "T1"] = "hands"
             stim[stim == "T2"] = "feet"
             raw.annotations.description = stim
-            data["run_%d" % run] = raw
+            data[str(idx)] = stim_channels_with_selected_ids(
+                raw, desired_event_id=self.events
+            )
+            idx += 1
 
-        return {"session_0": data}
+        return {"0": data}
 
     def data_path(
         self, subject, path=None, force_update=False, update_path=None, verbose=None
     ):
+        runs = [1, 2] + self.hand_runs + self.feet_runs
+
         if subject not in self.subject_list:
             raise (ValueError("Invalid subject number"))
 
         sign = "EEGBCI"
         get_dataset_path(sign, None)
-        paths = eegbci.load_data(
-            subject, runs=[1, 2] + self.hand_runs + self.feet_runs, verbose=verbose
-        )
+        paths = self._load_data(subject, runs=runs, verbose=verbose)
         return paths
+
+    def _load_data(self, subject, runs, path=None, force_update=False, verbose=None):
+        # Function to load the data run by run
+        if not hasattr(runs, "__iter__"):
+            runs = [runs]
+
+        # get local storage path
+        sign = "EEGBCI"
+        path = get_dataset_path(sign, path)
+
+        # fetch the file(s)
+        data_paths = []
+        for run in runs:
+            file_part = f"S{subject:03d}/S{subject:03d}R{run:02d}.edf"
+            url = BASE_URL + file_part
+            p = data_dl(url, sign, path, force_update, verbose)
+            data_paths.append(p)
+        return data_paths
