@@ -1,9 +1,9 @@
-"""
-SSVEP Exoskeleton dataset.
-"""
+"""SSVEP Exoskeleton dataset."""
 
 from mne.io import Raw
 
+from moabb.utils import depreciated_alias
+
 from . import download as dl
 from .base import BaseDataset
 
@@ -11,8 +11,9 @@ from .base import BaseDataset
 SSVEPEXO_URL = "https://zenodo.org/record/2392979/files/"
 
 
-class SSVEPExo(BaseDataset):
-    """SSVEP Exo dataset
+@depreciated_alias("SSVEPExo", "1.1")
+class Kalunga2016(BaseDataset):
+    """SSVEP Exo dataset.
 
     SSVEP dataset from E. Kalunga PhD in University of Versailles [1]_.
 
@@ -41,6 +42,13 @@ class SSVEPExo(BaseDataset):
     days, by the same operators, on the same hardware and in the same
     conditions.
 
+    Notes
+    -----
+    The events notation 17Hz and 21Hz were swapped after an investigation conducted
+    by @ponpopon.
+
+    .. versionadded:: 1.2.0
+
     references
     ----------
     .. [1] Emmanuel K. Kalunga, Sylvain Chevallier, Quentin Barthelemy. "Online
@@ -52,27 +60,26 @@ class SSVEPExo(BaseDataset):
         super().__init__(
             subjects=list(range(1, 13)),
             sessions_per_subject=1,
-            events={"13": 2, "17": 3, "21": 4, "rest": 1},
-            code="SSVEP Exoskeleton",
+            events={"13": 2, "17": 4, "21": 3, "rest": 1},
+            code="Kalunga2016",
             interval=[2, 4],
             paradigm="ssvep",
             doi="10.1016/j.neucom.2016.01.007",
         )
 
     def _get_single_subject_data(self, subject):
-        """Return the data of a single subject"""
+        """Return the data of a single subject."""
 
         out = {}
         paths = self.data_path(subject, update_path=True, verbose=False)
         for ii, path in enumerate(paths):
             raw = Raw(path, preload=True, verbose="ERROR")
-            out["run_%d" % ii] = raw
-        return {"session_0": out}
+            out[str(ii)] = raw
+        return {"0": out}
 
     def data_path(
         self, subject, path=None, force_update=False, update_path=None, verbose=None
     ):
-
         runs = {s + 1: n for s, n in enumerate([2] * 6 + [3] + [2] * 2 + [4, 2, 5])}
 
         if subject not in self.subject_list:
