@@ -1,4 +1,4 @@
-"""Motor Imagery Paradigms"""
+"""Motor Imagery Paradigms."""
 
 import abc
 import logging
@@ -29,12 +29,12 @@ class BaseMotorImagery(BaseParadigm):
     tmin: float (default 0.0)
         Start time (in second) of the epoch, relative to the dataset specific
         task interval e.g. tmin = 1 would mean the epoch will start 1 second
-        after the begining of the task as defined by the dataset.
+        after the beginning of the task as defined by the dataset.
 
     tmax: float | None, (default None)
-        End time (in second) of the epoch, relative to the begining of the
+        End time (in second) of the epoch, relative to the beginning of the
         dataset specific task interval. tmax = 5 would mean the epoch will end
-        5 second after the begining of the task as defined in the dataset. If
+        5 second after the beginning of the task as defined in the dataset. If
         None, use the dataset value.
 
     baseline: None | tuple of length 2
@@ -63,19 +63,15 @@ class BaseMotorImagery(BaseParadigm):
         channels=None,
         resample=None,
     ):
-        super().__init__()
-        self.filters = filters
-        self.events = events
-        self.channels = channels
-        self.baseline = baseline
-        self.resample = resample
-
-        if tmax is not None:
-            if tmin >= tmax:
-                raise (ValueError("tmax must be greater than tmin"))
-
-        self.tmin = tmin
-        self.tmax = tmax
+        super().__init__(
+            filters=filters,
+            events=events,
+            channels=channels,
+            baseline=baseline,
+            resample=resample,
+            tmin=tmin,
+            tmax=tmax,
+        )
 
     def is_valid(self, dataset):
         ret = True
@@ -110,7 +106,7 @@ class BaseMotorImagery(BaseParadigm):
 
 
 class SinglePass(BaseMotorImagery):
-    """Single Bandpass filter motot Imagery.
+    """Single Bandpass filter motor Imagery.
 
     Motor imagery paradigm with only one bandpass filter (default 8 to 32 Hz)
 
@@ -129,12 +125,12 @@ class SinglePass(BaseMotorImagery):
     tmin: float (default 0.0)
         Start time (in second) of the epoch, relative to the dataset specific
         task interval e.g. tmin = 1 would mean the epoch will start 1 second
-        after the begining of the task as defined by the dataset.
+        after the beginning of the task as defined by the dataset.
 
     tmax: float | None, (default None)
-        End time (in second) of the epoch, relative to the begining of the
+        End time (in second) of the epoch, relative to the beginning of the
         dataset specific task interval. tmax = 5 would mean the epoch will end
-        5 second after the begining of the task as defined in the dataset. If
+        5 second after the beginning of the task as defined in the dataset. If
         None, use the dataset value.
 
     baseline: None | tuple of length 2
@@ -151,7 +147,6 @@ class SinglePass(BaseMotorImagery):
 
     resample: float | None (default None)
         If not None, resample the eeg data with the sampling rate provided.
-
     """
 
     def __init__(self, fmin=8, fmax=32, **kwargs):
@@ -168,15 +163,14 @@ class FilterBank(BaseMotorImagery):
         filters=([8, 12], [12, 16], [16, 20], [20, 24], [24, 28], [28, 32]),
         **kwargs,
     ):
-        """init"""
+        """init."""
         super().__init__(filters=filters, **kwargs)
 
 
 class LeftRightImagery(SinglePass):
-    """Motor Imagery for left hand/right hand classification
+    """Motor Imagery for left hand/right hand classification.
 
     Metric is 'roc_auc'
-
     """
 
     def __init__(self, **kwargs):
@@ -193,10 +187,9 @@ class LeftRightImagery(SinglePass):
 
 
 class FilterBankLeftRightImagery(FilterBank):
-    """Filter Bank Motor Imagery for left hand/right hand classification
+    """Filter Bank Motor Imagery for left hand/right hand classification.
 
     Metric is 'roc_auc'
-
     """
 
     def __init__(self, **kwargs):
@@ -213,13 +206,12 @@ class FilterBankLeftRightImagery(FilterBank):
 
 
 class FilterBankMotorImagery(FilterBank):
-    """
-    Filter bank n-class motor imagery.
+    """Filter bank n-class motor imagery.
 
     Metric is 'roc-auc' if 2 classes and 'accuracy' if more
 
     Parameters
-    -----------
+    ----------
 
     events: List of str
         event labels used to filter datasets (e.g. if only motor imagery is
@@ -284,7 +276,6 @@ class FilterBankMotorImagery(FilterBank):
         return utils.dataset_search(
             paradigm="imagery",
             events=self.events,
-            total_classes=self.n_classes,
             interval=interval,
             has_all_events=False,
         )
@@ -298,13 +289,12 @@ class FilterBankMotorImagery(FilterBank):
 
 
 class MotorImagery(SinglePass):
-    """
-    N-class motor imagery.
+    """N-class motor imagery.
 
     Metric is 'roc-auc' if 2 classes and 'accuracy' if more
 
     Parameters
-    -----------
+    ----------
 
     events: List of str
         event labels used to filter datasets (e.g. if only motor imagery is
@@ -323,12 +313,12 @@ class MotorImagery(SinglePass):
     tmin: float (default 0.0)
         Start time (in second) of the epoch, relative to the dataset specific
         task interval e.g. tmin = 1 would mean the epoch will start 1 second
-        after the begining of the task as defined by the dataset.
+        after the beginning of the task as defined by the dataset.
 
     tmax: float | None, (default None)
-        End time (in second) of the epoch, relative to the begining of the
+        End time (in second) of the epoch, relative to the beginning of the
         dataset specific task interval. tmax = 5 would mean the epoch will end
-        5 second after the begining of the task as defined in the dataset. If
+        5 second after the beginning of the task as defined in the dataset. If
         None, use the dataset value.
 
     baseline: None | tuple of length 2
@@ -347,25 +337,27 @@ class MotorImagery(SinglePass):
         If not None, resample the eeg data with the sampling rate provided.
     """
 
-    def __init__(self, n_classes=2, **kwargs):
+    def __init__(self, n_classes=None, **kwargs):
         super().__init__(**kwargs)
         self.n_classes = n_classes
 
         if self.events is None:
             log.warning("Choosing from all possible events")
-        else:
+        elif self.n_classes is not None:
             assert n_classes <= len(self.events), "More classes than events specified"
 
     def is_valid(self, dataset):
         ret = True
         if not dataset.paradigm == "imagery":
             ret = False
-        if self.events is None:
+        elif self.n_classes is None and self.events is None:
+            pass
+        elif self.events is None:
             if not len(dataset.event_id) >= self.n_classes:
                 ret = False
         else:
             overlap = len(set(self.events) & set(dataset.event_id.keys()))
-            if not overlap >= self.n_classes:
+            if self.n_classes is not None and not overlap >= self.n_classes:
                 ret = False
         return ret
 
@@ -374,8 +366,8 @@ class MotorImagery(SinglePass):
         if self.events is None:
             for k, v in dataset.event_id.items():
                 out[k] = v
-                if len(out) == self.n_classes:
-                    break
+            if self.n_classes is None:
+                self.n_classes = len(out)
         else:
             for event in self.events:
                 if event in dataset.event_id.keys():
@@ -418,3 +410,6 @@ class FakeImageryParadigm(LeftRightImagery):
     @property
     def datasets(self):
         return [FakeDataset(["left_hand", "right_hand"], paradigm="imagery")]
+
+    def is_valid(self, dataset):
+        return dataset.paradigm == "imagery"
