@@ -1,14 +1,10 @@
-"""P300 Paradigms"""
+"""P300 Paradigms."""
 
-import abc
 import logging
 
-import mne
-import numpy as np
-import pandas as pd
-
 from moabb.datasets import utils
 from moabb.datasets.fake import FakeDataset
+from moabb.datasets.preprocessing import RawToEventsP300
 from moabb.paradigms.base import BaseParadigm
 
 
@@ -33,12 +29,12 @@ class BaseP300(BaseParadigm):
     tmin: float (default 0.0)
         Start time (in second) of the epoch, relative to the dataset specific
         task interval e.g. tmin = 1 would mean the epoch will start 1 second
-        after the begining of the task as defined by the dataset.
+        after the beginning of the task as defined by the dataset.
 
     tmax: float | None, (default None)
-        End time (in second) of the epoch, relative to the begining of the
+        End time (in second) of the epoch, relative to the beginning of the
         dataset specific task interval. tmax = 5 would mean the epoch will end
-        5 second after the begining of the task as defined in the dataset. If
+        5 second after the beginning of the task as defined in the dataset. If
         None, use the dataset value.
 
     baseline: None | tuple of length 2
@@ -66,20 +62,18 @@ class BaseP300(BaseParadigm):
         baseline=None,
         channels=None,
         resample=None,
+        ignore_relabelling=False,
     ):
-        super().__init__()
-        self.filters = filters
-        self.events = events
-        self.channels = channels
-        self.baseline = baseline
-        self.resample = resample
-
-        if tmax is not None:
-            if tmin >= tmax:
-                raise (ValueError("tmax must be greater than tmin"))
-
-        self.tmin = tmin
-        self.tmax = tmax
+        self.ignore_relabelling = ignore_relabelling
+        super().__init__(
+            filters=filters,
+            events=events,
+            channels=channels,
+            baseline=baseline,
+            resample=resample,
+            tmin=tmin,
+            tmax=tmax,
+        )
 
     def is_valid(self, dataset):
         ret = True
@@ -94,101 +88,13 @@ class BaseP300(BaseParadigm):
         # we should verify list of channels, somehow
         return ret
 
-    @abc.abstractmethod
-    def used_events(self, dataset):
-        pass
-
-    def process_raw(self, raw, dataset, return_epochs=False):  # noqa: C901
-        # find the events, first check stim_channels then annotations
-        stim_channels = mne.utils._get_stim_channel(None, raw.info, raise_error=False)
-        if len(stim_channels) > 0:
-            events = mne.find_events(raw, shortest_event=0, verbose=False)
-        else:
-            events, _ = mne.events_from_annotations(raw, verbose=False)
-
-        channels = () if self.channels is None else self.channels
-
-        # picks channels
-        picks = mne.pick_types(raw.info, eeg=True, stim=False, include=channels)
-
-        # get event id
+    def _get_events_pipeline(self, dataset):
         event_id = self.used_events(dataset)
-
-        # pick events, based on event_id
-        try:
-            if type(event_id["Target"]) is list and type(event_id["NonTarget"]) == list:
-                event_id_new = dict(Target=1, NonTarget=0)
-                events = mne.merge_events(events, event_id["Target"], 1)
-                events = mne.merge_events(events, event_id["NonTarget"], 0)
-                event_id = event_id_new
-            events = mne.pick_events(events, include=list(event_id.values()))
-        except RuntimeError:
-            # skip raw if no event found
-            return
-
-        # get interval
-        tmin = self.tmin + dataset.interval[0]
-        if self.tmax is None:
-            tmax = dataset.interval[1]
-        else:
-            tmax = self.tmax + dataset.interval[0]
-
-        X = []
-        for bandpass in self.filters:
-            fmin, fmax = bandpass
-            # filter data
-            raw_f = raw.copy().filter(
-                fmin, fmax, method="iir", picks=picks, verbose=False
-            )
-            # epoch data
-            baseline = self.baseline
-            if baseline is not None:
-                baseline = (
-                    self.baseline[0] + dataset.interval[0],
-                    self.baseline[1] + dataset.interval[0],
-                )
-                bmin = baseline[0] if baseline[0] < tmin else tmin
-                bmax = baseline[1] if baseline[1] > tmax else tmax
-            else:
-                bmin = tmin
-                bmax = tmax
-            epochs = mne.Epochs(
-                raw_f,
-                events,
-                event_id=event_id,
-                tmin=bmin,
-                tmax=bmax,
-                proj=False,
-                baseline=baseline,
-                preload=True,
-                verbose=False,
-                picks=picks,
-                on_missing="ignore",
-            )
-            if bmin < tmin or bmax > tmax:
-                epochs.crop(tmin=tmin, tmax=tmax)
-            if self.resample is not None:
-                epochs = epochs.resample(self.resample)
-            # rescale to work with uV
-            if return_epochs:
-                X.append(epochs)
-            else:
-                X.append(dataset.unit_factor * epochs.get_data())
-
-        inv_events = {k: v for v, k in event_id.items()}
-        labels = np.array([inv_events[e] for e in epochs.events[:, -1]])
-
-        if return_epochs:
-            X = mne.concatenate_epochs(X)
-        elif len(self.filters) == 1:
-            # if only one band, return a 3D array
-            X = X[0]
-        else:
-            # otherwise return a 4D
-            X = np.array(X).transpose((1, 2, 3, 0))
-
-        metadata = pd.DataFrame(index=range(len(labels)))
-        return X, labels, metadata
+        return RawToEventsP300(
+            event_id=event_id,
+            interval=dataset.interval,
+            ignore_relabelling=self.ignore_relabelling,
+        )
 
     @property
     def datasets(self):
@@ -206,7 +112,7 @@ class BaseP300(BaseParadigm):
 
 
 class SinglePass(BaseP300):
-    """Single Bandpass filter P300
+    """Single Bandpass filter P300.
 
     P300 paradigm with only one bandpass filter (default 1 to 24 Hz)
 
@@ -225,12 +131,12 @@ class SinglePass(BaseP300):
     tmin: float (default 0.0)
         Start time (in second) of the epoch, relative to the dataset specific
         task interval e.g. tmin = 1 would mean the epoch will start 1 second
-        after the begining of the task as defined by the dataset.
+        after the beginning of the task as defined by the dataset.
 
     tmax: float | None, (default None)
-        End time (in second) of the epoch, relative to the begining of the
+        End time (in second) of the epoch, relative to the beginning of the
         dataset specific task interval. tmax = 5 would mean the epoch will end
-        5 second after the begining of the task as defined in the dataset. If
+        5 second after the beginning of the task as defined in the dataset. If
         None, use the dataset value.
 
     baseline: None | tuple of length 2
@@ -247,7 +153,6 @@ class SinglePass(BaseP300):
 
     resample: float | None (default None)
         If not None, resample the eeg data with the sampling rate provided.
-
     """
 
     def __init__(self, fmin=1, fmax=24, **kwargs):
@@ -255,18 +160,26 @@ class SinglePass(BaseP300):
             raise (ValueError("P300 does not take argument filters"))
         super().__init__(filters=[[fmin, fmax]], **kwargs)
 
+    @property
+    def fmax(self):
+        return self.filters[0][1]
+
+    @property
+    def fmin(self):
+        return self.filters[0][0]
+
 
 class P300(SinglePass):
-    """P300 for Target/NonTarget classification
+    """P300 for Target/NonTarget classification.
 
     Metric is 'roc_auc'
-
     """
 
     def __init__(self, **kwargs):
-        if "events" in kwargs.keys():
-            raise (ValueError("P300 dont accept events"))
-        super().__init__(events=["Target", "NonTarget"], **kwargs)
+        if "events" not in kwargs.keys():
+            super().__init__(events=["Target", "NonTarget"], **kwargs)
+        else:
+            super().__init__(**kwargs)
 
     def used_events(self, dataset):
         return {ev: dataset.event_id[ev] for ev in self.events}
@@ -282,3 +195,6 @@ class FakeP300Paradigm(P300):
     @property
     def datasets(self):
         return [FakeDataset(["Target", "NonTarget"], paradigm="p300")]
+
+    def is_valid(self, dataset):
+        return dataset.paradigm == "p300"
